@@ -15,8 +15,8 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-// $Name: IMKIT_0_4_3 $
-// $Id: aux_keyhelper.cpp,v 1.3 2004/04/29 03:32:46 yamaken Exp $
+// $Name: IMKIT_0_4_4 $
+// $Id: aux_keyhelper.cpp,v 1.4 2004/04/29 14:41:00 yamaken Exp $
 
 #include <qevent.h>
 #include <qcopchannel_qws.h>
@@ -32,6 +32,7 @@ void
 KeyHelperForwarder::on_activate(void) {
   if (QCopChannel::isRegistered("QPE/KeyHelper")) {
     // instruct KeyHelper to send back key events to IMKit
+    qDebug("KeyHelperForwarder::on_activate() send hook() to KeyHelper");
     QCopEnvelope envelope("QPE/KeyHelper", "hook(QString)");
 
     envelope << QString("QPE/IME");
@@ -41,6 +42,7 @@ KeyHelperForwarder::on_activate(void) {
 void
 KeyHelperForwarder::on_deactivate(void) {
   if (QCopChannel::isRegistered("QPE/KeyHelper")) {
+    qDebug("KeyHelperForwarder::on_activate() send unhook() to KeyHelper");
     QCopEnvelope envelope("QPE/KeyHelper", "unhook()");
   }
 }
@@ -56,8 +58,9 @@ KeyHelperForwarder::on_input(QKeyEvent &e) {
 void
 KeyHelperForwarder::forward(QKeyEvent &e) {
   qDebug("KeyHelperForwarder::forward()"
-         " txt=%s, ascii=%d, keycode=%d, accepted=%d",
-         e.text().latin1(), e.ascii(), e.key(), e.isAccepted());
+         " txt=%s, ascii=%x, keycode=%x, is_press=%d, accepted=%d",
+         e.text().latin1(), e.ascii(), e.key(),
+         (e.type() == QEvent::KeyPress), e.isAccepted());
   QCopEnvelope envelope("QPE/KeyHelper", "event(int,int,int,int,int)");
   int unicode, modifiers;
   bool is_press;
