@@ -15,8 +15,8 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-// $Name: IMKIT_0_4_3 $
-// $Id: keyfilter.cpp,v 1.12 2004/04/12 02:14:58 yamaken Exp $
+// $Name: IMKIT_0_4_4 $
+// $Id: keyfilter.cpp,v 1.13 2004/04/29 14:41:01 yamaken Exp $
 
 #include <ctype.h>
 #include "keyfilter.h"
@@ -219,7 +219,12 @@ CascadeKeyFilter::remove_till(CascadeKeyFilter *end) {
 
 void
 CascadeKeyFilter::input(QKeyEvent *e) {
-  if (is_active() && !e->isAccepted()) {
+  bool is_dummy_input;
+
+  is_dummy_input = (e->key() == IMKIT_NON_UNICODE_CHAR
+                    && e->ascii() == 0
+                    && e->state() == 0);
+  if (is_active() && !e->isAccepted() && !is_dummy_input) {
     on_input(*e);
 
     if (e->isAccepted()) {
